setClass("cacorporateplus",representation(S="cabasicresults",
    DataMatrix="matrix", rows="numeric", cols="numeric", 
  rowlabels="character", collabels="character", 
  Rprinccoord="matrix", Cprinccoord="matrix", Rstdcoord="matrix", Cstdcoord="matrix",
    inertiasum="numeric", inertias="matrix", inertias2="matrix",comps="matrix",
  printdims="numeric", maxaxes="numeric",catype="character",mj="numeric",mi="numeric",pcc="matrix",Jmass="matrix",
Imass="matrix",Trend="matrix",Z="matrix"))
